@@ -50,9 +50,10 @@ function(var,month=c(1),infile,outfile,nc34=3){
 
   id <- nc_open(infile)
 
-  # get information about dimensions
-
-  dimnames <- names(id$dim)
+  # get information about dimensions and attributes
+  
+  dimnames   <- names(id$dim)
+  global_att <- ncatt_get(id,0)
 
  # check standard_names of dimensions
     for (i in 1:length(dimnames)){
@@ -141,16 +142,6 @@ function(var,month=c(1),infile,outfile,nc34=3){
 
   if (length(month)==sum(month %in% mon)){
 
-  seas <- array(NA,dim=c(length(month),length(yl)))
-
-  for (i in 1:length(yl)){
-    for (j in 1:length(month)){
-    	dum <- which(mon==month[j]&year==yl[i])
-    	if (length(dum)==0)(dum <- NA)
-	      seas[j,i] <- dum
-    }
-  }
-
   target <- array(NA,dim=c(length(lon),length(lat),1))
   tbnds <- array(NA, dim=c(2,1))
 
@@ -168,10 +159,27 @@ function(var,month=c(1),infile,outfile,nc34=3){
     compression = NA
   }
 
-    cmsaf_info <- (paste("cmsaf::multimonmean of month(s): ",month," for variable ",var,sep=""))
+    dummy_month <- paste(month,collapse=", ")
+    cmsaf_info <- (paste("cmsaf::multimonmean of month(s): ",dummy_month," for variable ",var,sep=""))
     target[is.na(target)] <- v_missing_value
     nb2 <- c(0,1)
-
+    
+    # prepare global attributes
+    global_att_default <- c("institution","title","summary","id","creator_name",
+                            "creator_email","creator_url","creator_type","publisher_name",
+                            "publisher_email","publisher_url","publisher_type",
+                            "references","keywords_vocabulary","keywords","project",
+                            "standard_name_vocabulary","geospatial_lat_units",
+                            "geospatial_lon_units","geospatial_lat_resolution",
+                            "geospatial_lon_resolution","platform_vocabulary","platform",
+                            "instrument_vocabulary","instrument","date_created","product_version",
+                            "producer","version","dataset_version","source")
+    
+    global_att_list <- names(global_att)
+    
+    global_att_list <- global_att_list[toupper(global_att_list) %in% toupper(global_att_default)]
+    global_att <- global_att[global_att_list]
+    
     x <- ncdim_def(name="lon",units=lon_units,vals=lon)
     y <- ncdim_def(name="lat",units=lat_units,vals=lat)
     t <- ncdim_def(name="time",units=t_units,vals=0,unlim=TRUE)
@@ -203,6 +211,12 @@ function(var,month=c(1),infile,outfile,nc34=3){
     ncatt_put(ncnew,"lat","axis",lat_axis,prec="text")
 
     ncatt_put(ncnew,0,"Info",info,prec="text")
+    
+    if (length(global_att_list)>0){
+      for (iglob in 1:length(global_att_list)){
+        ncatt_put(ncnew,0,global_att_list[iglob],global_att[iglob][[1]],prec="text")
+      }
+    }
 
   # get data and calculate seasonal means
 
@@ -210,23 +224,29 @@ function(var,month=c(1),infile,outfile,nc34=3){
   dum_dat <- array(NA,dim=c(length(lon),length(lat),length(month)))
   count <- 1
   for (i in 1:length(yl)){
-    mon_dummy <- seas[,i]
-    if (sum(is.na(mon_dummy))==0){
-      for (j in 1:length(month)){
-	  dum_dat[,,j] <- ncvar_get(id,var,start=c(1,1,mon_dummy[j]),count=c(-1,-1,1),collapse_degen=FALSE)
+    mon_dummy <- NULL
+    for (j in 1:length(month)){
+      dum <- which(mon==month[j]&year==yl[i])
+      if(length(dum)>0){
+        mon_dummy <- append(mon_dummy,dum)
+        dumdum_dat <- ncvar_get(id,var,start=c(1,1,dum[1]),count=c(-1,-1,length(dum)),collapse_degen=FALSE)
+        dumdum_dat <- rowMeans(dumdum_dat,dims=2,na.rm=T)
+        dum_dat[,,j] <- dumdum_dat
       }
-	  cat("\r","apply multi monthly mean ",count," of ",(length(yl)),sep="")
-	  mean_data <- rowMeans(dum_dat,dims=2,na.rm=T)
-	  mean_data[is.na(mean_data)] <- v_missing_value
-	  tdum <- min(time1[mon_dummy])
-	  tbnds[1,1] <- min(time1[mon_dummy])
-	  tbnds[2,1] <- max(time1[mon_dummy])
-	  ncvar_put(ncnew,var1,mean_data,start=c(1,1,count),count=c(-1,-1,1))
-	  ncvar_put(ncnew,t,tdum,start=count,count=1)
-	  ncvar_put(ncnew,var2,tbnds,start=c(1,count),count=c(-1,1))
-	  count <- count+1
-     }
-   }
+    }
+    if(sum(!is.na(dum_dat))!=0){
+      cat("\r","apply multi monthly mean ",count," of ",(length(yl)),sep="")
+      mean_data <- rowMeans(dum_dat,dims=2,na.rm=T)
+      mean_data[is.na(mean_data)] <- v_missing_value
+      tdum <- min(time1[mon_dummy])
+      tbnds[1,1] <- min(time1[mon_dummy])
+      tbnds[2,1] <- max(time1[mon_dummy])
+      ncvar_put(ncnew,var1,mean_data,start=c(1,1,count),count=c(-1,-1,1))
+      ncvar_put(ncnew,t,tdum,start=count,count=1)
+      ncvar_put(ncnew,var2,tbnds,start=c(1,count),count=c(-1,1))
+      count <- count+1
+    }
+  }
  nc_close(id)
 
  nc_close(ncnew)
